@@ -118,16 +118,6 @@ has uses_implied_rate => (
     isa => 'Maybe[Bool]',
 );
 
-=head2 spot
-
-Current spot price
-
-=cut
-
-has spot => (
-    is => 'ro',
-);
-
 =head2 asset_symbol
 
 Symbol name of the asset (Asset or Currency)
@@ -280,4 +270,12 @@ has asset_class => (
     isa => 'Str',
 );
 
+has use_official_ohlc => (
+    is => 'ro',
+);
+
+has spot_db_args => (
+    is => 'ro',
+);
+
 1;
